==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/draw_prot.h <==
/* draw.c */
void	init_draw( void );
void	print_wrn( const char *s, ... );
void	print_err( const char *s, ... );
void	print_msg( flg_msg_t flg, const char *s, ... );
void	print_msg_mbr( chr_t *chr, flg_msg_t flg, const char *s, ... );
void	print_msg_n(
	curs_attr_n_t attr_n, flg_msg_t flg, const char *s, ...
);
void	print_msg_attr(
	curs_attr_t *attr, flg_msg_t flg, const char *s, ...
);
void	more( flg_msg_t flg, bool_t flg_mul );
void	wipe_msg( void );
void	clr_msg( void );
void	redraw_msg( void );
void	print_log( void );
void	print_log_back( long idx );
long	get_ls_msg_idx( void );
long	get_ls_msg_page( void );
bool_t	set_msg_mul_line( bool_t flg );
bool_t	chk_msg_mul_line( void );
long	get_ls_msg_n( void );
void	draw_ls_msg( long n );
void	print_str(
	long scrn_x, long scrn_y, flg_print_t flg,
	const char *s, ...
);
void	print_str_n(
	long scrn_x, long scrn_y, curs_attr_n_t attr_n,
	const char *s, ...
);
void	print_str_attr(
	long scrn_x, long scrn_y, curs_attr_t *attr,
	const char *s, ...
);
void	wipe_all( void );
void	redraw_all( void );
void	draw_map( long map_x, long map_y, long dx, long dy );
void	redraw_map( void );
void	draw_party( void );
void	draw_mbr( mbr_t *mbr );
void	draw_square( void );
void	draw_all_mnstr( void );
void	draw_mnstr( mnstr_t *p );
void	draw_door( long dr_n );
void	draw_item( item_t *p );
void	draw_trap( trap_t *p );
void	draw_menu( draw_menu_t *data );
void	draw_menu_num( long figure, long sel_n, char num[] );
char	*get_str_open_win_item( char *kind );
char	*get_str_branch( char *kind );
bool_t	wipe_menu( void );
void	draw_all_mbr_stat( void );
void	draw_mbr_stat( mbr_t *mbr );
void	draw_misc_stat( void );
void	vfx_crtcl( chr_kind_t kind, long x, long y );
void	set_vfx_attr( curs_attr_n_t n );
void	vfx_arw( chr_kind_t kind, pos_t *bgn, pos_t *end, long c, long len );
void	vfx_arw_line(
	pos_t *bgn, pos_t *end, const char *str, long len,
	long frame, long clr_frame, bool_t flg_clr
);
void	vfx_arw_mul_line(
	long arw_n, pos_t *bgn, pos_t *end, const char *str, long len,
	long frame, long clr_frame, bool_t flg_clr
);
void	vfx_num( chr_t *p, long n );
void	draw_num( long map_x, long map_y, long n, chr_kind_t kind );
void	draw_blast( long map_x, long map_y, blast_t *p );
void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
void	draw_mbr_data( mbr_t *org, mbr_t *mbr, data_n_t n, bool_t flg_rev );
data_n_t	next_mbr_data(
	long page_n, data_n_t n, long d,
	mbr_data_edit_kind_t edit_kind
);
bool_t	gets_mbr_name( mbr_t *mbr_p );
bool_t	gets_mbr_face( mbr_t *mbr_p );
bool_t	gets_race_name( mbr_t *mbr );
void	draw_edit_class_all(
	class_t *org, class_t *dst,
	edit_class_t sel_n, bool_t flg_sel_add
);
void	draw_edit_class(
	class_t *org, class_t *dst, edit_class_t n,
	bool_t flg_sel, bool_t flg_sel_add
);
bool_t	gets_class_name( char *name );
void	game_gets( char *s, long len );
void	pick_cntrl_str( char *s );
void	set_crsr( long x, long y );
void	reset_crsr( void );
pos_t	*get_map_draw_pos( void );
long	get_max_line( void );
rate_t	get_vfx_wait( void );
rate_t	set_vfx_wait( rate_t n );
flg_vfx_mbr_t	get_flg_vfx_mbr( void );
flg_vfx_mbr_t	set_flg_vfx_mbr( flg_vfx_mbr_t flg );
flg_vfx_mnstr_t	get_flg_vfx_mnstr( void );
flg_vfx_mnstr_t	set_flg_vfx_mnstr( flg_vfx_mnstr_t flg );
void	wait_clock( long frame );
long	read_char( long *p );
long	read_char_wait( long *p );
long	read_esc( long *p );
long	get_key( bool_t flg_clr_msg );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/draw_prot.h <==
/* draw.c */
void	init_draw( void );
void	init_clock( bool_t flg_measure );
void	print_wrn( const char *s, ... );
void	print_err( const char *s, ... );
void	print_words( char *name, const char *s, ... );
char	*get_words_line( char *p, long max_len );
void	print_msg_mbr( chr_t *chr, flg_msg_t flg, const char *s, ... );
void	print_msg_find( chr_t *chr, flg_msg_t flg, const char *s, ... );
void	print_msg( flg_msg_t flg, const char *s, ... );
void	more( flg_msg_t flg, bool_t flg_mul );
void	wipe_msg( void );
void	clr_msg( void );
void	redraw_msg( void );
void	print_log( void );
void	print_log_back( long idx );
long	get_ls_msg_idx( void );
long	get_ls_msg_page( void );
bool_t	set_msg_mul_line( bool_t flg );
bool_t	chk_msg_mul_line( void );
long	get_ls_msg_n( void );
void	draw_ls_msg( long n );
void	print_str( long scrn_x, long scrn_y, const char *s, ... );
void	wipe_all( void );
void	redraw_all( void );
void	draw_map( long map_x, long map_y, long dx, long dy );
void	redraw_map( void );
void	draw_chr( chr_t *chr );
void	draw_party( void );
void	draw_mbr( mbr_t *mbr );
void	draw_square( void );
void	draw_all_mnstr( void );
void	draw_mnstr( mnstr_t *p );
void	draw_all_pet( void );
void	draw_pet( pet_t *p );
void	draw_door( long dr_n );
void	draw_item( item_t *p );
void	draw_trap( trap_t *p );
void	draw_menu( draw_menu_t *data );
void	draw_menu_num( long figure, long sel_n, char num[] );
char	*get_str_open_win_item( char *kind );
char	*get_str_branch( char *kind );
bool_t	wipe_menu( void );
void	draw_all_mbr_stat( void );
void	draw_mbr_stat( mbr_t *mbr );
void	draw_misc_stat( void );
void	vfx_crtcl( chr_kind_t kind, long x, long y );
void	get_vfx_attr( curs_attr_t *attr );
void	set_vfx_attr( const curs_attr_t *attr );
void	set_vfx_attr_n( curs_attr_n_t n );
void	vfx_arw( chr_kind_t kind, pos_t *bgn, pos_t *end, long c, long len );
void	vfx_arw_line(
	pos_t *bgn, pos_t *end, const char *str, long len,
	long frame, long clr_frame, bool_t flg_clr
);
void	vfx_arw_mul_line(
	long arw_n, pos_t *bgn, pos_t *end, const char *str, long len,
	long frame, long clr_frame, bool_t flg_clr
);
void	vfx_num( chr_t *p, long n );
void	draw_num( long map_x, long map_y, long n, chr_kind_t kind );
void	draw_blast( long map_x, long map_y, blast_t *p, char *str );
void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
void	draw_mbr_data( mbr_t *org, mbr_t *mbr, data_n_t n, bool_t flg_rev );
data_n_t	next_mbr_data(
	long page_n, data_n_t n, long d,
	mbr_data_edit_kind_t edit_kind
);
bool_t	gets_mbr_name( mbr_t *mbr_p );
bool_t	gets_mbr_face( mbr_t *mbr_p );
bool_t	gets_race_name( mbr_t *mbr );
void	draw_edit_class_all(
	class_t *org, class_t *dst,
	edit_class_t sel_n, bool_t flg_sel_add
);
void	draw_edit_class(
	class_t *org, class_t *dst, edit_class_t n,
	bool_t flg_sel, bool_t flg_sel_add
);
bool_t	gets_class_name( char *name );
bool_t	game_gets( long x, long y, char *s, long len, bool_t flg_pick );
void	pick_cntrl_str( char *s );
void	set_crsr( long x, long y );
void	reset_crsr( void );
pos_t	*get_map_draw_pos( void );
rate_t	get_vfx_wait( void );
rate_t	set_vfx_wait( rate_t n );
flg_vfx_mbr_t	get_flg_vfx_mbr( void );
flg_vfx_mbr_t	set_flg_vfx_mbr( flg_vfx_mbr_t flg );
flg_vfx_mnstr_t	get_flg_vfx_mnstr( void );
flg_vfx_mnstr_t	set_flg_vfx_mnstr( flg_vfx_mnstr_t flg );
void	wait_clock( long frame );
long	read_char( long *p );
long	read_char_wait( long *p );
long	read_esc( long *p );
long	get_key( bool_t flg_clr_msg );
long	get_key_std( bool_t flg_clr_msg );
long	get_key_x68k( bool_t flg_clr_msg );
long	get_key_buf_char( void );
bool_t	set_key_buf_str( const char *s );
